summaryrefslogtreecommitdiff
path: root/src/char
diff options
context:
space:
mode:
authorBen Longbons <b.r.longbons@gmail.com>2014-09-02 15:11:06 -0700
committerBen Longbons <b.r.longbons@gmail.com>2014-09-30 13:49:26 -0700
commit77563ec532c8b51134c3020fb3c70a8bed8457fb (patch)
tree51e285a203956681a04b08257fa06f8b113a5981 /src/char
parent0d3df507b4c4fe1dde086cd85a78179c8bcefcf9 (diff)
downloadtmwa-77563ec532c8b51134c3020fb3c70a8bed8457fb.tar.gz
tmwa-77563ec532c8b51134c3020fb3c70a8bed8457fb.tar.bz2
tmwa-77563ec532c8b51134c3020fb3c70a8bed8457fb.tar.xz
tmwa-77563ec532c8b51134c3020fb3c70a8bed8457fb.zip
Rename enum Option to Opt0
Diffstat (limited to 'src/char')
-rw-r--r--src/char/char.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/char/char.cpp b/src/char/char.cpp
index d5e887b..4f52663 100644
--- a/src/char/char.cpp
+++ b/src/char/char.cpp
@@ -807,7 +807,7 @@ CharPair *make_new_char(Session *s, CharName name, const Stats6& stats, uint8_t
cd.sp = cd.max_sp;
cd.status_point = 0;
cd.skill_point = 0;
- cd.option = static_cast<Option>(0x0000); // Option is only declared
+ cd.option = static_cast<Opt0>(0x0000); // Opt0 is only declared
cd.karma = 0;
cd.manner = 0;
cd.party_id = PartyId();
@@ -2608,7 +2608,7 @@ void parse_char(Session *s)
fixed_6d.char_select.gloves = ItemNameId();
fixed_6d.char_select.cape = ItemNameId();
fixed_6d.char_select.misc1 = ItemNameId();
- fixed_6d.char_select.option = Option();
+ fixed_6d.char_select.option = Opt0();
fixed_6d.char_select.unused = 0;
// this was buggy until the protocol became generated